# DeepAffex APIv2 Protocol Buffers

This repository contains pre-compiled Python 3 Protocol Buffers for the
NuraLogix DeepAffex API.

For more information, please visit https://deepaffex.ai/developers-api
